import { Observable } from 'rxjs';
import { ICodeNamedEntity, ICoreEnvironment, IQueryResult, IRequestOptions } from '../../../interfaces';
import { HttpClientService } from '../../../services/http-client.service';
import { ICompanyAddress, ICompanyAddressList, ICompanyBankAccount, ICompanyBankAccountList, ICompanyContact, ICompanyNote, ICompanyProfile, ICompanyProfileList } from '../interfaces';
import { CompanyActualContract, CompanyState, CompanyVersion } from '../models';
import { Query, QueryBase } from '../../../models/query.model';
export declare class CompanyService {
    private _http;
    core: ICoreEnvironment;
    private _companyBaseUrl;
    private _contactBaseUrl;
    private _companyPaymentMethodBaseUrl;
    private _noteBaseUrl;
    private _addressBaseUrl;
    private _stateBaseUrl;
    private _companyActualStates;
    constructor(_http: HttpClientService, core: ICoreEnvironment);
    companyPostQuery(query: QueryBase, options?: IRequestOptions): Observable<IQueryResult<ICompanyProfileList>>;
    getParentCompanies(currentId: number): Observable<ICompanyProfile[]>;
    companyGetEntity(entityId: number, options?: IRequestOptions): Observable<ICompanyProfile>;
    companyPostEntity(entity: ICompanyProfile, options?: IRequestOptions): Observable<ICompanyProfile>;
    companyPublish(entity: ICompanyProfile, options?: IRequestOptions): Observable<ICompanyProfile>;
    getStateList(queryDto: QueryBase, options?: IRequestOptions): Observable<CompanyState[]>;
    statePostQuery(queryDto: Query<{}>, options?: IRequestOptions): Observable<IQueryResult<ICodeNamedEntity>>;
    getVersionList(queryDto: QueryBase, options?: IRequestOptions): Observable<CompanyVersion[]>;
    getCompanyActualContractStates(): CompanyActualContract[];
    getHasCompanyActualContractName(hasActualContract: boolean): CompanyActualContract;
    contactPostQuery(queryDto: QueryBase, options?: IRequestOptions): Observable<IQueryResult<ICompanyContact>>;
    contactGetEntity(entityId: number, options?: IRequestOptions): Observable<ICompanyContact>;
    contactPostEntity(entity: ICompanyContact, options?: IRequestOptions): Observable<ICompanyContact>;
    contactPostDelete(entity: ICompanyContact, options?: IRequestOptions): Observable<{}>;
    bankAccountPostQuery(companyId?: number, options?: IRequestOptions): Observable<IQueryResult<ICompanyBankAccountList>>;
    searchByAccountNumber(companyId?: number, accountNumber?: string): Observable<IQueryResult<ICompanyBankAccountList>>;
    bankAccountGetEntity(entityId: number, options?: IRequestOptions): Observable<ICompanyBankAccount>;
    bankAccountPostEntity(entity: ICompanyBankAccount, options?: IRequestOptions): Observable<ICompanyBankAccount>;
    bankAccountPostDelete(entity: ICompanyBankAccount, options?: IRequestOptions): Observable<{}>;
    getPaymentStateList(query: Query<{}>, options?: IRequestOptions): Observable<ICodeNamedEntity[]>;
    notePostQuery(queryDto: QueryBase, options?: IRequestOptions): Observable<IQueryResult<ICompanyNote>>;
    noteGetEntity(entityId: number, options?: IRequestOptions): Observable<ICompanyNote>;
    notePostEntity(entity: ICompanyNote, options?: IRequestOptions): Observable<ICompanyNote>;
    notePostDelete(entity: ICompanyNote, options?: IRequestOptions): Observable<{}>;
    addressPostQuery(queryDto: QueryBase, options?: IRequestOptions): Observable<IQueryResult<ICompanyAddressList>>;
    addressGetEntity(entityId: number, options?: IRequestOptions): Observable<ICompanyAddress>;
    addressPostEntity(entity: ICompanyAddress, options?: IRequestOptions): Observable<ICompanyAddress>;
    addressPostDelete(entity: ICompanyAddress, options?: IRequestOptions): Observable<{}>;
    getSubstituteParameters(): Observable<ICodeNamedEntity[]>;
    getCardReferenceList(paymentTypeId: number): Observable<ICodeNamedEntity[]>;
    private _getBankAccountFilter;
}
