import { Observable } from 'rxjs';
import { VocabularyService } from './vocabulary-service';
import { SearchFlight } from '../models/search-flight.model';
import { SearchResult } from '../models/search-result.model';
import { Passenger } from '../models/passenger.model';
import { City } from '../models/city';
import { CompanyType } from '../enums/company-type.enum';
export declare class SysadminVocabularyService implements VocabularyService {
    companyRegion: {
        code: string;
        name: string;
        description: any;
        id: number;
    }[];
    companyType: {
        code: CompanyType;
        name: string;
        description: any;
        id: number;
    }[];
    notHorseTypes: {
        code: CompanyType;
        name: string;
        description: any;
        id: number;
    }[];
    agentCompanyType: {
        code: CompanyType;
        name: string;
        description: any;
        id: number;
    }[];
    companyAddressType: {
        code: string;
        name: string;
        description: any;
        id: number;
    }[];
    companyStates: {
        id: number;
        code: string;
        name: string;
    }[];
    genders: {
        code: boolean;
        name: string;
    }[];
    userGenders: {
        code: string;
        name: string;
        description: any;
        id: number;
    }[];
    permissions: {
        code: string;
        name: string;
    }[];
    profileType: {
        code: CompanyType;
        name: string;
        description: any;
        id: number;
    }[];
    stateMachine: {
        id: number;
        code: string;
        name: string;
    }[];
    state: {
        id: number;
        code: string;
        name: string;
        stateMachineCode: string;
    }[];
    userProfileState: any[];
    userProfileStateAgg: any;
    agentProfileState: any[];
    agencyProfileState: any[];
    agencyBranchState: any[];
    providerProfileState: any[];
    horseCompanyState: any[];
    agencyContractState: any[];
    travelerProfileState: any[];
    reportState: any[];
    identityClientState: any[];
    providerType: {
        id: number;
        code: string;
        name: string;
        group: string;
    }[];
    gTargetBranches: {
        id: number;
        code: string;
        name: string;
    }[];
    travelportPnrServiceRole: {
        id: number;
        code: string;
        name: string;
    }[];
    serviceGroup: {
        id: number;
        code: string;
        name: string;
    }[];
    specialFolderPermission: {
        code: string;
        name: string;
    }[];
    reportKind: {
        id: number;
        code: string;
        name: string;
    }[];
    unitType: {
        length: string;
        weight: string;
    };
    unitKind: {
        id: number;
        code: string;
        name: string;
        typeCode: string;
    }[];
    geographicalLocationType: {
        id: number;
        code: string;
        name: string;
    }[];
    documentKinds: {
        id: number;
        code: string;
        name: string;
        typeCode: string;
    }[];
    travelDocumentKinds: {
        id: number;
        code: string;
        name: string;
        typeCode: string;
    }[];
    travelerPaymentFormType: {
        id: number;
        code: string;
        name: string;
    }[];
    travelerPaymentFormTypeCode: {
        agencyPayment: string;
        agentVoucher: string;
        cash: string;
        certificate: string;
        check: string;
        creditCard: string;
        debitCard: string;
        directPayment: string;
        guarantee: string;
        miscFormOfPayment: string;
        paymentAdvice: string;
        requisition: string;
        ticketNumber: string;
        unitedNations: string;
        voucher: string;
    };
    creditCardType: {
        id: number;
        name: string;
    }[];
    guaranteeAgencyType: {
        id: number;
        name: string;
    }[];
    guaranteeType: {
        id: number;
        name: string;
    }[];
    miscFormOfPaymentCategory: {
        id: number;
        name: string;
    }[];
    otherPaymentType: {
        id: number;
        name: string;
    }[];
    phoneNumberType: {
        id: number;
        name: string;
    }[];
    requisitionCategory: {
        id: number;
        name: string;
    }[];
    requisitionType: {
        id: number;
        name: string;
    }[];
    voucherType: {
        id: number;
        name: string;
    }[];
    airFareType: {
        id: number;
        name: string;
    }[];
    preferencePurpose: {
        id: number;
        name: string;
    }[];
    coachCompartmentType: {
        id: number;
        name: string;
    }[];
    seatArrangementType: {
        id: number;
        name: string;
    }[];
    seatingType: {
        id: number;
        name: string;
    }[];
    ticketFulfillmentType: {
        id: number;
        name: string;
    }[];
    grantType: {
        code: string;
        name: string;
    }[];
    identityScope: {
        code: string;
        name: string;
    }[];
    constructor();
    nameById(vocabulary: any[], id: number): any;
    codeById(vocabulary: any[], id: number): any;
    fieldById(vocabulary: any[], id: number, field: string): any;
    getByFieldName(vocabulary: any[], filterList: any[], filterFieldName: string, searchFieldName: string): any[];
    sortByFieldName(items: any[], field: string, orderBy?: boolean): any[];
    stateByStateMachineCode(code: string): any[];
    getCities(pattern: string): Observable<City[]>;
    searchFlights(options: SearchFlight): Observable<SearchResult>;
    searchPassengers(pattern: string): Observable<Passenger[]>;
    private _aggregation;
}
